==> STexampleData_1.2.0.tar.gz: STexampleData/inst/doc/STexampleData_overview.R <==
## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(echo = TRUE)

## ---- eval=FALSE--------------------------------------------------------------
#  install.packages("BiocManager")
#  BiocManager::install("STexampleData")

## ---- eval=FALSE--------------------------------------------------------------
#  remotes::install_github("lmweber/STexampleData")

## ---- message=FALSE-----------------------------------------------------------
library(ExperimentHub)

## -----------------------------------------------------------------------------
# create ExperimentHub instance
eh <- ExperimentHub()

# query STexampleData datasets
myfiles <- query(eh, "STexampleData")
myfiles

# metadata
md <- as.data.frame(mcols(myfiles))

## ---- message=FALSE-----------------------------------------------------------
library(STexampleData)
library(SpatialExperiment)

## -----------------------------------------------------------------------------
# load object
spe <- Visium_humanDLPFC()

# alternatively: using ExperimentHub query
# spe <- myfiles[[1]]
# alternatively: using ExperimentHub ID
# spe <- myfiles[["EH6708"]]

# check object
spe
dim(spe)
assayNames(spe)
rowData(spe)
colData(spe)
spatialData(spe)
head(spatialCoords(spe))
imgData(spe)

## ---- message=FALSE-----------------------------------------------------------
# load object
spe <- Visium_mouseCoronal()

# alternatively: using ExperimentHub query
# spe <- myfiles[[2]]
# alternatively: using ExperimentHub ID
# spe <- myfiles[["EH6709"]]

# check object
spe

## ---- message=FALSE-----------------------------------------------------------
# load object
spe <- seqFISH_mouseEmbryo()

# alternatively: using ExperimentHub query
# spe <- myfiles[[3]]
# alternatively: using ExperimentHub ID
# spe <- myfiles[["EH6710"]]

# check object
spe

## -----------------------------------------------------------------------------
sessionInfo()

==> STexampleData_1.8.0.tar.gz: STexampleData/inst/doc/STexampleData_overview.R <==
## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(echo = TRUE)

## ---- eval=FALSE--------------------------------------------------------------
#  install.packages("BiocManager")
#  BiocManager::install("STexampleData")

## ---- eval=FALSE--------------------------------------------------------------
#  install.packages("remotes")
#  remotes::install_github("lmweber/STexampleData", build_vignettes = TRUE)

## ---- message=FALSE-----------------------------------------------------------
library(SpatialExperiment)
library(STexampleData)

## ---- message=FALSE-----------------------------------------------------------
# load object
spe <- Visium_humanDLPFC()

# check object
spe
dim(spe)
assayNames(spe)
rowData(spe)
colData(spe)
head(spatialCoords(spe))
imgData(spe)

## ---- message=FALSE-----------------------------------------------------------
# load object
spe <- Visium_mouseCoronal()
# check object
spe

## ---- message=FALSE-----------------------------------------------------------
# load object
spe <- seqFISH_mouseEmbryo()
# check object
spe

## ---- message=FALSE-----------------------------------------------------------
# load object
spe <- ST_mouseOB()
# check object
spe

## ---- message=FALSE-----------------------------------------------------------
# load object
spe <- SlideSeqV2_mouseHPC()
# check object
spe

## ---- message=FALSE-----------------------------------------------------------
library(ExperimentHub)

## ---- message=FALSE-----------------------------------------------------------
# create ExperimentHub instance
eh <- ExperimentHub()

# query STexampleData datasets
myfiles <- query(eh, "STexampleData")
myfiles

# metadata
md <- as.data.frame(mcols(myfiles))

## ---- message=FALSE-----------------------------------------------------------
# load Visium_humanDLPFC dataset using ExperimentHub query
spe <- myfiles[[1]]
spe

## ---- message=FALSE-----------------------------------------------------------
# load Visium_humanDLPFC dataset using ExperimentHub ID
spe <- myfiles[["EH7538"]]
spe

## -----------------------------------------------------------------------------
sessionInfo()
